/* ========================================================================
 * DOM-based Routing
 * Based on http://goo.gl/EUTi53 by Paul Irish
 *
 * Only fires on body classes that match. If a body class contains a dash,
 * replace the dash with an underscore when adding it to the object below.
 *
 * .noConflict()
 * The routing is enclosed within an anonymous function so that you can
 * always reference jQuery with $, even when in .noConflict() mode.
 *
 * Google CDN, Latest jQuery
 * To use the default WordPress version of jQuery, go to lib/config.php and
 * remove or comment out: add_theme_support('jquery-cdn');
 * ======================================================================== */

(function ($, document, window, TEMPLATE_URL, API_URL, undefined) {
  "use strict";

  var $document = $(document),
    $window = $(window),
    $body;

  function assign_bootstrap_mode() {
    var mode;
    switch (true) {
      case Modernizr.mq("(max-width: 575px)"):
        mode = "mode-xs";
        break;
      case Modernizr.mq("(max-width: 767px)"):
        mode = "mode-sm";
        break;
      case Modernizr.mq("(max-width: 991px)"):
        mode = "mode-md";
        break;
      case Modernizr.mq("(max-width: 1199px)"):
        mode = "mode-lg";
        break;
      default:
        mode = "mode-xl";
        break;
    }
    $body.removeClass("mode-xs mode-sm mode-md mode-lg").addClass(mode);
  }

  function initShowcaseHome() {
    $(".showcase-home__slider").slick({
      infinite: true,
      arrows: false,
      dots: true,
      lazyLoad: "ondemand",
      slidesToShow: 1,
      slidesToScroll: 1,
      appendDots: $(".showcase__controls-pager"),
      fade: true,
      autoplay: true,
      autoplaySpeed: 2000,
    });
  }

  /** Se for usar âncoras no projeto, descomenta esse bloco de código e use a rolagem suave. */
  /*
  function goToSection() {

    $('a[href*="#"]').on('click', function (e) {

        var divId = this.href.split("#")[1], $div = $('#' + divId);

        if(divId === 'top' || $div.length){
            e.preventDefault();

            var position = $div.length ? $div.position().top : 0;
            $('body, html').stop().animate({scrollTop: position}, 500, 'swing');

        }

    });

  } 
  */

  // Use this variable to set up the common and page specific functions. If you
  // rename this variable, you will also need to rename the namespace below.
  var Roots = {
    // All pages
    common: {
      init: function () {
        $("a[rel~=external]").attr("target", "_blank");
        // JavaScript to be fired on all pages

        $body = $("body");
               
        $window.on("resize", $.throttle(100, assign_bootstrap_mode));
        assign_bootstrap_mode();

        // $(".open-login", '#login-collapse').hover(function(){
        //     var dropdownMenu = $("#login-collapse");
        //     var dropdownMenu = $("#login-collapse");
        //     dropdownMenu.toggleClass("collapse show");
            
        // });

        // $("#cities").change(function () {
        //   location.href = $(this).val();
        // });

        $('.js-example-basic-single').select2({dropdownParent: $('#choose-city')});
        

        $(".offcanvas-toggle").click(function () {
          $("#bars").toggleClass("open");
        });

        $("[data-trigger]").on("click", function (e) {
          e.preventDefault();
          e.stopPropagation();
          var offcanvas_id = $(this).attr("data-trigger");
          $(offcanvas_id).toggleClass("show");
          $("body").toggleClass("offcanvas-active");
          $(".screen-overlay").toggleClass("show");
        });

        $(".btn-close, .screen-overlay").click(function (e) {
          $(".screen-overlay").removeClass("show");
          $(".mobile-offcanvas").removeClass("show");
          $("body").removeClass("offcanvas-active");
          $("#bars").removeClass("open");
        });

        $(".custom-plans__slider").slick({
          arrows: true,
          dots: false,
          infinite: false,
          slidesToShow: 4,
          prevArrow: '<span class="icon icon-chevron-left"></span>',
          nextArrow: '<span class="icon icon-chevron-right"></span>',
          rows: 0,
          autoplay: true,
          responsive: [
            {
              breakpoint: 1024,
              settings: {
                slidesToShow: 2,
                slidesToScroll: 2,
              },
            },
            {
              breakpoint: 600,
              settings: {
                arrows: true,
                slidesToShow: 1,
                slidesToScroll: 1,
              },
            },
          ],
        });

        // Fetch all the forms we want to apply custom Bootstrap validation styles to
        var forms = document.getElementsByClassName('form-order');
        // Loop over them and prevent submission
        var validation = Array.prototype.filter.call(forms, function(form) {
          form.addEventListener('submit', function(event) {
            if (form.checkValidity() === false) {
              event.preventDefault();
              event.stopPropagation();
            }
            form.classList.add('was-validated');
          }, false);
        });
      },
    },
    // Home page
    home: {
      init: function () {
        // JavaScript to be fired on the home page
        $document.on('click', '[data-accessbility-control]', function (e) {
          e.preventDefault();
          $body.trigger($(this).data('accessbility-control'));
        });
        
        initShowcaseHome();

        $(".internet-home__slider").slick({
          arrows: true,
          dots: false,
          infinite: false,
          slidesToShow: 4,
          prevArrow: '<span class="icon icon-chevron-left"></span>',
          nextArrow: '<span class="icon icon-chevron-right"></span>',
          autoplay: true,
          responsive: [
            {
              breakpoint: 1024,
              settings: {
                slidesToShow: 2,
                slidesToScroll: 2,
              },
            },
            {
              breakpoint: 600,
              settings: {
                arrows: true,
                slidesToShow: 1,
                slidesToScroll: 1,
              },
            },
          ],
        });

        // $(".open-login").hover(function() {
        //     $('.login-collapse').collapse('show');
        //   },function() {
        //     $('.login-collapse').collapse('hide');
        //   }
        // );
      },
    },
  };

  // The routing fires all common scripts, followed by the page specific scripts.
  // Add additional events for more control over timing e.g. a finalize event
  var UTIL = {
    fire: function (func, funcname, args) {
      var namespace = Roots;
      funcname = funcname === undefined ? "init" : funcname;
      if (
        func !== "" &&
        namespace[func] &&
        typeof namespace[func][funcname] === "function"
      ) {
        namespace[func][funcname](args);
      }
    },
    loadEvents: function () {
      UTIL.fire("common");

      $.each(document.body.className.replace(/-/g, "_").split(/\s+/), function (
        i,
        classnm
      ) {
        UTIL.fire(classnm);
      });
    },
  };

  $(document).ready(UTIL.loadEvents);
})($, document, window, TEMPLATE_URL, API_URL); // Fully reference jQuery after this point.
