/**
 * Styleswitch stylesheet switcher built on jQuery
 * Under an Attribution, Share Alike License
 * By Kelvin Luck ( http://www.kelvinluck.com/ )
 **/

(function ($, window, undefined) {
    'use strict';

    var $body,
        $window,
        fontSizeIndex,
        fontSizes = [50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150],
        cookie = 'tamahofonte';

    function init() {
        change(store.get(cookie, 100))
    }

    function filterSize(fontSize) {
        fontSizeIndex = fontSizes.indexOf(fontSize);
        if (fontSizeIndex === -1) {
            fontSize = 100;
            filterSize(fontSize);
        }

        return fontSize;
    }

    function change(fontSize) {
        fontSize = filterSize(fontSize);

        $body.removeClass(function (index, css) {
            return (css.match(/(^|\s)fontsize-\S+/g) || []).join(' ');
        });

        if (fontSize != 100) {
            var cssClass = 'fontsize-custom fontsize-' + fontSize,
                removeClass;
            if(fontSize > 100) {
                cssClass += ' fontsize-more';
                removeClass = 'fontsize-less';
            } else {
                cssClass += ' fontsize-less';
                removeClass = 'fontsize-more';
            }
            $body.addClass(cssClass).removeClass(removeClass);
            store.set(cookie, fontSize);
        } else {
            store.remove(cookie);
        }
    }

    function set(index) {
        var newFontSizeIndex = fontSizeIndex + index;
        if (fontSizes[newFontSizeIndex]) {
            fontSizeIndex = newFontSizeIndex;
            change(fontSizes[fontSizeIndex]);
            $window.trigger('resize');
        }
    }

    function reset() {
        change(100);
        $window.trigger('resize');
    }

    function increase() {
        set(1);
    }

    function decrease() {
        set(-1);
    }

    $(function () {
        $body = $('body');
        $window = $(window);

        init();

        $body
            .on('fontsize-increase', increase)
            .on('fontsize-reset', reset)
            .on('fontsize-decrease', decrease);
    });

// /cookie functions
})(jQuery, window);