(function ($, document, window) {
    "use strict";

    var $document = $(document);

    function setFormAlert($form, type, message, scroll) {
        var $alert = $form.find('.alert-pc-ajax');

        if (!$alert.length) {
            $alert = $('<div class="alert alert-pc-ajax" />');

            if($form.data('pc-form-wrapper-alert')) {
                $($form.data('pc-form-wrapper-alert')).prepend($alert);
            } else {
                $form.prepend($alert);
            }
        }

        $alert.removeClass('alert-info alert-success alert-danger')
            .addClass('alert-' + type)
            .html(message);

        if (scroll) {

            var offset = 0;

            if($form.data('pc-form-offset-to')){
                var offsetTo = $form.data('pc-form-offset-to');

                if ($.isNumeric(parseInt(offsetTo, 10))) {
                    offset = offsetTo;
                } else {
                    var $el = $(offsetTo);
                    offset = $el.offset().top;
                }
            } else {
                offset = $form.offset().top;
            }

            if($form.data('pc-form-offset-add')){
                var offsetAdd = $form.data('pc-form-offset-add');
                offset += offsetAdd;
            }

            $('body, html').animate({
                scrollTop: offset
            }, 300);
        }
    }

    function submitForm(e) {
        e.preventDefault();

        var $form = $(e.currentTarget),
            $submit = $form.find('[data-form-pc-ajax-submit]'),
            action = $form.attr('action'),
            formmail = $form.data('form-pc-ajax'),
            scroll = !$form.filter('[data-form-pc-ajax-disablescroll]').length,
            clear = !$form.filter('[data-form-pc-ajax-disableclear]').length,
            alert = !$form.filter('[data-form-pc-ajax-disablealert]').length,
            redirectUrl = $form.data('form-pc-ajax-redirect'),
            redirect = $form.filter('[data-form-pc-ajax-redirect]').length && redirectUrl !== "",
            url = action + 'mailer/index.php?formmail=' + encodeURI(formmail);

        if (!$submit.length) {
            $submit = $form.find('input[type=submit], button').first();
        }

        function enableSubmit() {

            var val = $submit.data('old-val'),
                method;

            if ($submit.is('input')) {
                method = 'val';
            } else {
                method = 'text';
            }

            $submit.prop('disabled', false);
            $submit[method](val);
        }

        function disableSubmit() {
            var val,
                method;

            if ($submit.is('input')) {
                method = 'val';
            } else {
                method = 'text';
            }

            $submit.prop('disabled', true)
                .data('old-val', $submit[method]());

            $submit[method]('Aguarde...');
        }

        function beforeSubmit(arr, $form) {
            if ($submit.prop('disabled')) {
                return false;
            }
            disableSubmit();

            var data = {};
            $.each(arr, function (k, v) {
                data[v.name] = v.value;
            });

            if (window.dataLayer) {
                dataLayer.push({
                    event: 'pc_ajaxform_submitting',
                    data: data
                });
            }
            $form.trigger('pc-ajax-form-submitting', [data]);
        }

        function onSuccess(data) {
            var type, message, localRedirectUrl = false, localRedirectTimeout;

            if (data && data.message) {
                type = data.success ? 'success' : 'danger';
                message = data.message;
                localRedirectUrl = data.redirect_url || false;
                if(localRedirectUrl) {
                    localRedirectTimeout = data.redirect_timeout || 7000;
                }
            } else {
                type = 'info';
                message = 'Requisição com sucesso, porém resultado não esperado';
            }

            if(alert) {
                setFormAlert($form, type, message, scroll);
            }

            if (window.dataLayer) {
                dataLayer.push({
                    event: 'pc_ajaxform_' + type,
                    data: data
                });
            }
            $form.trigger('pc-ajax-form-' + type, [data]);

            if(!localRedirectUrl) {
                if (clear && type === 'success' && !redirect) {
                    $form.clearForm();
                } else if(redirect && type === 'success'){
                    window.location = encodeURI(redirectUrl);
                }

                enableSubmit();
            } else {
                setTimeout(function() {
                    window.location = localRedirectUrl;
                }, localRedirectTimeout)
            }
        }

        function onError(data) {
            var message = '',
                type = 'info';

            if (data.responseText) {
                message = '<strong>Falha recebida ao enviar mensagem:</strong><br/><br/>' + data.responseText;
            }

            if (window.dataLayer) {
                dataLayer.push({
                    event: 'pc_ajaxform_' + type,
                    data: data
                });
            }
            $form.trigger('pc-ajax-form-' + type);

            enableSubmit();

            if(alert) {
                setFormAlert($form, type, message, scroll);
            }
        }

        $form.ajaxSubmit({
            url: url,
            success: onSuccess,
            error: onError,
            beforeSubmit: beforeSubmit,
            dataType: 'json',
            type: 'post'
        });
    }


    $.fn.formPcSetFormAlert = function(type, message, scroll) {
        scroll = scroll ? scroll : true;
        setFormAlert(this, type, message, scroll);
    };

    $document.on('submit', 'form[data-form-pc-ajax]', submitForm);
})(jQuery, document, window); // Fully reference jQuery after this point.
