<?php
/**
 * Roots includes
 *
 * The $roots_includes array determines the code library included in your theme.
 * Add or remove files to the array as needed. Supports child theme overrides.
 *
 * Please note that missing files will produce a fatal error.
 *
 * @link https://github.com/roots/roots/pull/1042
 */

$roots_includes = array(
	'lib/rest-api.php',                     // Routes Apis
    'lib/apis.php',                         // Rest Apis
	'lib/acfs.php',                         // ACF functions
	'lib/utils.php',                        // Utility functions
	'lib/init.php',                         // Initial theme setup and constants
	'lib/wrapper.php',                      // Theme wrapper class
	'lib/config.php',                       // Configuration
	'lib/titles.php',                       // Page titles
	'lib/nav.php',                          // Custom nav modifications
	'lib/posttypes.php',                    // Post Types
	'lib/gallery.php',                      // Custom [gallery] modifications
	'lib/sidebar.php',                      // Sidebar
	'lib/scripts.php',                      // Scripts and stylesheets
	'lib/shortcodes.php',                   // Shortcode
	'lib/extras.php',                       // Custom functions
	'lib/custom.php',                       // Funções da Ponto
    'lib/social-networks-nav-menu.php',     // Social Networks Nav Walker
    'lib/Bootstrap4NavMenuWalker.php',       // Walker para o Boostrap 4
);

foreach ( $roots_includes as $file ) {
	if ( ! $filepath = locate_template( $file ) ) {
		trigger_error( sprintf( __( 'Error locating %s for inclusion', 'roots' ), $file ), E_USER_ERROR );
	}

	require_once $filepath;
}
unset( $file, $filepath );

add_filter( 'site_transient_update_plugins', 'ext_core_acf_remove_update_notification' );

// Disable ACF update notifications
function ext_core_acf_remove_update_notification( $value ) {

	if($value->response) {
		unset( $value->response['advanced-custom-fields/acf.php'] );
	}

	return $value;
}

/**
 * Responsável por trazer as notícias destacadas. Se não forem configuradas no admin, o número máximo de postagens é
 * recuperado com base em $countPost. $field é o campo de relação no admin e $post_id (opcional) é o ID da página do field.
 *
 * @param $postType String
 * @param $countPost int
 * @param $field String
 * @param $post_id int
 *
 * @return mixed ObjectPost
 */

function get_news_highlights($postType, $countPost, $field, $post_id = false)
{

    global $post;

    $listagem = get_field($field, $post_id);
    $total    = $countPost;
    $count    = $listagem != '' ? count($listagem) : 0;

    if (!is_array($listagem)) {
        $listagem = array();
    }

    if ($count < $total) {
        $posts = array();
        if ($listagem) {
            foreach ($listagem as $destaque) {
                $posts[] = $destaque->ID;
            }
        }

        $outras = new WP_Query(array(
            'post_type'      => $postType,
            'posts_per_page' => $total - $count,
            'post__not_in'   => $posts
        ));

        while ($outras->have_posts()) {
            $outras->the_post();
            $listagem[] = $post;
        }

        wp_reset_postdata();
        unset($posts, $outras);
    }

    return $listagem;
}

/*
* Filter the number to replace comma with dot
*
* @param string
* @return integer
*/
add_filter( 'number_format_i18n', function( $formatted ) {
    return str_replace( '.', ',', $formatted );
});

/**
 * Retorna a URL base para o Assine
 * @return string
 */
 function get_assine_url()
 {
     static $assineUrl;
     $assineUrl = home_url('internet');
     return $assineUrl;
 }

 /**
  * Register new field to options general
  */

 function minhas_configuracoes() {
	register_setting(
		'general',
		'address',
		array(
			'sanitize_callback' => function( $value ) {
				if ( !$value ) {
					add_settings_error(
						'address',
						esc_attr( 'address_erro' ),
						'Insira um endereço válido.',
						'error'
					);
					return get_option( 'address' );
				}
				return $value;
			},
		)
	);

	register_setting(
		'general',
		'phone',
		array(
			'sanitize_callback' => function( $value ) {
				if ( !$value ) {
					add_settings_error(
						'phone',
						esc_attr( 'phone_erro' ),
						'Insira um telefone/celular válido.',
						'error'
					);
					return get_option( 'phone' );
				}
				return $value;
			},
		)
	);

	register_setting(
		'general',
		'email',
		array(
			'sanitize_callback' => function( $value ) {
				if ( !$value ) {
					add_settings_error(
						'email',
						esc_attr( 'email_erro' ),
						'Insira um e-mail válido.',
						'error'
					);
					return get_option( 'email' );
				}
				return $value;
			},
		)
	);
 
	add_settings_field(
		'address',
		'Endereço completo',
		function( $args ) {
			$options = get_option( 'address' );
			?>
            <input
				type="text"
				id="<?php echo esc_attr( $args['label_for'] ); ?>"
				name="address"
				value="<?php echo esc_attr( $options ); ?>"
                class="regular-text">
			<?php
		},
		'general',
		'default',
		[
			'label_for' => 'address_html_id',
			'class'     => 'classe-html-tr',
		]
	);

	add_settings_field(
		'phone',
		'Telefone',
		function( $args ) {
			$options = get_option( 'phone' );
			?>
            <input
				type="text"
				id="<?php echo esc_attr( $args['label_for'] ); ?>"
				name="phone"
				value="<?php echo esc_attr( $options ); ?>"
                class="regular-text">
			<?php
		},
		'general',
		'default',
		[
			'label_for' => 'phone_html_id',
			'class'     => 'classe-html-tr',
		]
	);

	add_settings_field(
		'email',
		'E-mail',
		function( $args ) {
			$options = get_option( 'email' );
			?>
            <input
				type="text"
				id="<?php echo esc_attr( $args['label_for'] ); ?>"
				name="email"
				value="<?php echo esc_attr( $options ); ?>"
                class="regular-text">
			<?php
		},
		'general',
		'default',
		[
			'label_for' => 'email_html_id',
			'class'     => 'classe-html-tr',
		]
	);
}
add_action( 'admin_init', 'minhas_configuracoes' );

/**
 * Redireciona para a página principal
 */
add_filter( 'template_redirect', function () {
	if ( is_main_site() && is_front_page()) {
		wp_redirect( home_url( '/santana/' ) );
		die;
	}
}, 200 );

// function gnex_category_rewrite_rule() {
// 	add_rewrite_tag(
//         '%servico%',
//         '([^/]+)'
//     );
//     add_rewrite_rule(
//         '^assine/([^/]+)/?',
//         'index.php?pagename=assine&servico=$matches[1]',
//         'top'
//     );
// }
// add_action('init',  __NAMESPACE__ . '\\gnex_category_rewrite_rule', 10, 0);


// function my_logged_in_redirect() {
     
//     if ( is_page('assine') ) 
//     {
//         wp_redirect( home_url( '/assine/internet'));
//         die;
//     }
     
// }
// add_action( 'template_redirect', 'my_logged_in_redirect' );